@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -137,15 +137,14 @@ python::object mcmc_layered_overlap_sweep_parallel(python::object omcmc_states,
         overlap_block_state::dispatch(dispatch);
     }
 
-    std::vector<std::shared_ptr<rng_t>> rngs;
-    init_rngs(rngs, rng);
+    parallel_rng<rng_t>::init(rng);
 
     std::vector<std::tuple<double, size_t, size_t>> rets(N);
 
     #pragma omp parallel for schedule(runtime)
     for (size_t i = 0; i < N; ++i)
     {
-        auto& rng_ = get_rng(rngs, rng);
+        auto& rng_ = parallel_rng<rng_t>::get(rng);
         rets[i] = sweeps[i]->run(rng_);
     }
 
