@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -93,7 +93,7 @@ def load_koblenz_dir(dirname):
 
 def get_koblenz_network_data(name):
     with tempfile.TemporaryFile(mode='w+b') as ftemp:
-        response = urlopen('http://konect.cc/files/download.tsv.%s.tar.bz2' % name)
+        response = urlopen('http://konect.uni-koblenz.de/downloads/tsv/%s.tar.bz2' % name)
         buflen = 1 << 20
         while True:
             buf = response.read(buflen)
