@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,9 +22,9 @@ from __future__ import division, absolute_import, print_function
 
 import numpy
 
-from .. import GraphView, PropertyMap, ungroup_vector_property,\
-     group_vector_property, infect_vertex_property, edge_endpoint_property, \
-     _prop
+from .. import GraphView, PropertyMap, VertexPropertyMap, \
+    ungroup_vector_property, group_vector_property, infect_vertex_property, \
+    edge_endpoint_property, _prop
 from .cairo_draw import *
 from .cairo_draw import _vdefaults, _edefaults
 from .. draw import sfdp_layout, random_layout, _avg_edge_distance, \
@@ -142,7 +142,7 @@ class GraphWidget(Gtk.DrawingArea):
         ----------
         g : :class:`~graph_tool.Graph`
             Graph to be drawn.
-        pos : :class:`~graph_tool.PropertyMap`
+        pos : :class:`~graph_tool.VertexPropertyMap`
             Vector-valued vertex property map containing the x and y coordinates of
             the vertices.
         vprops : dict (optional, default: ``None``)
@@ -153,9 +153,9 @@ class GraphWidget(Gtk.DrawingArea):
             Dictionary with the edge properties. Individual properties may also be
             given via the ``edge_<prop-name>`` parameters, where ``<prop-name>`` is
             the name of the property.
-        vorder : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+        vorder : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
             If provided, defines the relative order in which the vertices are drawn.
-        eorder : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+        eorder : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
             If provided, defines the relative order in which the edges are drawn.
         nodesfirst : bool (optional, default: ``False``)
             If ``True``, the vertices are drawn first, otherwise the edges are.
@@ -165,7 +165,7 @@ class GraphWidget(Gtk.DrawingArea):
             Parameter ``K`` passed to :func:`~graph_tool.draw.sfdp_layout`.
         multilevel : bool (optional, default: ``False``)
             Parameter ``multilevel`` passed to :func:`~graph_tool.draw.sfdp_layout`.
-        display_props : list of :class:`~graph_tool.PropertyMap` instances (optional, default: ``None``)
+        display_props : list of :class:`~graph_tool.VertexPropertyMap` instances (optional, default: ``None``)
             List of properties to be displayed when the mouse passes over a vertex.
         display_props_size : float (optional, default: ``11.``)
             Font size used to display the vertex properties.
@@ -208,11 +208,11 @@ class GraphWidget(Gtk.DrawingArea):
             representing the vertices currently selected, and ``vprops`` and
             ``eprops`` are dictionaries with the vertex and edge properties
             currently being used by the layout.
-        vertex_* : :class:`~graph_tool.PropertyMap` or arbitrary types (optional, default: ``None``)
+        vertex_* : :class:`~graph_tool.VertexPropertyMap` or arbitrary types (optional, default: ``None``)
             Parameters following the pattern ``vertex_<prop-name>`` specify the
             vertex property with name ``<prop-name>``, as an alternative to the
             ``vprops`` parameter.
-        edge_* : :class:`~graph_tool.PropertyMap` or arbitrary types (optional, default: ``None``)
+        edge_* : :class:`~graph_tool.EdgePropertyMap` or arbitrary types (optional, default: ``None``)
             Parameters following the pattern ``edge_<prop-name>`` specify the edge
             property with name ``<prop-name>``, as an alternative to the ``eprops``
             parameter.
@@ -576,7 +576,7 @@ class GraphWidget(Gtk.DrawingArea):
         cr.paint()
         cr.restore()
 
-        if self.picked is not None or self.picked is not False:
+        if self.selected.fa.sum() > 0:
             # draw immediate neighborhood
             if self.selected.fa.sum() == 1:
                 vprops = dict(**self.vprops)
@@ -1138,7 +1138,7 @@ class GraphWindow(Gtk.Window):
         ----------
         g : :class:`~graph_tool.Graph`
             Graph to be drawn.
-        pos : :class:`~graph_tool.PropertyMap`
+        pos : :class:`~graph_tool.VertexPropertyMap`
             Vector-valued vertex property map containing the x and y coordinates of
             the vertices.
         geometry : tuple
@@ -1151,9 +1151,9 @@ class GraphWindow(Gtk.Window):
             Dictionary with the edge properties. Individual properties may also be
             given via the ``edge_<prop-name>`` parameters, where ``<prop-name>`` is
             the name of the property.
-        vorder : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+        vorder : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
             If provided, defines the relative order in which the vertices are drawn.
-        eorder : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+        eorder : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
             If provided, defines the relative order in which the edges are drawn.
         nodesfirst : bool (optional, default: ``False``)
             If ``True``, the vertices are drawn first, otherwise the edges are.
@@ -1182,7 +1182,7 @@ _window_list = []
 
 def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
                        eorder=None, nodesfirst=False, geometry=(500, 400),
-                       update_layout=True, async=False, no_main=False, **kwargs):
+                       update_layout=True, sync=True, main=True, **kwargs):
     r"""
     Display an interactive GTK+ window containing the given graph.
 
@@ -1190,7 +1190,7 @@ def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be drawn.
-    pos : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+    pos : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
         Vector-valued vertex property map containing the x and y coordinates of
         the vertices. If not given, it will be computed using :func:`sfdp_layout`.
     vprops : dict (optional, default: ``None``)
@@ -1201,9 +1201,9 @@ def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
         Dictionary with the vertex properties. Individual properties may also be
         given via the ``edge_<prop-name>`` parameters, where ``<prop-name>`` is
         the name of the property.
-    vorder : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+    vorder : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
         If provided, defines the relative order in which the vertices are drawn.
-    eorder : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+    eorder : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
         If provided, defines the relative order in which the edges are drawn.
     nodesfirst : bool (optional, default: ``False``)
         If ``True``, the vertices are drawn first, otherwise the edges are.
@@ -1211,19 +1211,19 @@ def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
         Window geometry.
     update_layout : bool (optional, default: ``True``)
         If ``True``, the layout will be updated dynamically.
-    async : bool (optional, default: ``False``)
-        If ``True``, run asynchronously. (Requires :mod:`IPython`)
-    no_main : bool (optional, default: ``False``)
-        If ``True``, the GTK+ main loop will not be called.
+    sync : bool (optional, default: ``True``)
+        If ``False``, run asynchronously. (Requires :mod:`IPython`)
+    main : bool (optional, default: ``True``)
+        If ``False``, the GTK+ main loop will not be called.
     **kwargs
         Any extra parameters are passed to :class:`~graph_tool.draw.GraphWindow`,
         :class:`~graph_tool.draw.GraphWidget` and :func:`~graph_tool.draw.cairo_draw`.
 
     Returns
     -------
-    pos : :class:`~graph_tool.PropertyMap`
+    pos : :class:`~graph_tool.VertexPropertyMap`
         Vector vertex property map with the x and y coordinates of the vertices.
-    selected : :class:`~graph_tool.PropertyMap` (optional, only if ``output is None``)
+    selected : :class:`~graph_tool.VertexPropertyMap` (optional, only if ``output is None``)
         Boolean-valued vertex property map marking the vertices which were
         selected interactively.
 
@@ -1243,8 +1243,8 @@ def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
                       nodesfirst, update_layout, **kwargs)
     win.show_all()
     _window_list.append(win)
-    if not no_main:
-        if async:
+    if main:
+        if not sync:
             # just a placeholder for a proper main loop integration with gtk3 when
             # ipython implements it
             import IPython.lib.inputhook
