@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -138,7 +138,7 @@ def random_graph(N, deg_sampler, directed=True,
     -------
     random_graph : :class:`~graph_tool.Graph`
         The generated graph.
-    blocks : :class:`~graph_tool.PropertyMap`
+    blocks : :class:`~graph_tool.VertexPropertyMap`
         A vertex property map with the block values. This is only returned if
         ``block_membership is not None``.
 
@@ -549,7 +549,7 @@ def random_rewire(g, model="configuration", n_iter=1, edge_sweep=True,
         respective vertices, as specified via the ``block_membership``
         parameter. The value of ``p`` should be a number proportional to the
         probability of such an edge existing in the generated graph.
-    block_membership : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+    block_membership : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
         If supplied, the graph will be rewired to conform to a blockmodel
         ensemble. The value must be a vertex property map which defines the
         block of each vertex.
@@ -567,7 +567,7 @@ def random_rewire(g, model="configuration", n_iter=1, edge_sweep=True,
         some probabilistic models, and should be sufficiently fast for sparse
         graphs, but otherwise it may result in many repeated attempts for
         certain corner-cases in which edges are difficult to swap.
-    pin : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+    pin : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
         Edge property map which, if provided, specifies which edges are allowed
         to be rewired. Edges for which the property value is ``1`` (or ``True``)
         will be left unmodified in the graph.
@@ -1142,7 +1142,7 @@ def graph_union(g1, g2, intersection=None, props=None, include=False,
        First graph in the union.
     g2 : :class:`~graph_tool.Graph`
        Second graph in the union.
-    intersection : :class:`~graph_tool.PropertyMap` (optional, default: ``None``)
+    intersection : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
        Vertex property map owned by `g2` which maps each of its vertices
        to vertex indexes belonging to `g1`. Negative values mean no mapping
        exists, and thus both vertices in `g1` and `g2` will be present in the
@@ -1358,7 +1358,7 @@ def triangulation(points, type="simple", periodic=False):
     -------
     triangulation_graph : :class:`~graph_tool.Graph`
         The generated graph.
-    pos : :class:`~graph_tool.PropertyMap`
+    pos : :class:`~graph_tool.VertexPropertyMap`
         Vertex property map with the Cartesian coordinates.
 
     See Also
@@ -1651,7 +1651,7 @@ def geometric_graph(points, radius, ranges=None):
     -------
     geometric_graph : :class:`~graph_tool.Graph`
         The generated graph.
-    pos : :class:`~graph_tool.PropertyMap`
+    pos : :class:`~graph_tool.VertexPropertyMap`
         A vertex property map with the position of each vertex.
 
     Notes
@@ -1743,7 +1743,7 @@ def price_network(N, m=1, c=None, gamma=1, directed=True, seed_graph=None):
         Constant factor added to the probability of a vertex receiving an edge
         (see notes below).
     gamma : float (optional, default: ``1``)
-        Preferential attachment power (see notes below).
+        Preferential attachment exponent (see notes below).
     directed : bool (optional, default: ``True``)
         If ``True``, a Price network is generated. If ``False``, a
         Barabási-Albert network is generated.
@@ -1768,9 +1768,15 @@ def price_network(N, m=1, c=None, gamma=1, directed=True, seed_graph=None):
 
         \pi \propto k^\gamma + c
 
-    where :math:`k` is the in-degree of the vertex (or simply the degree in the
-    undirected case). If :math:`\gamma=1`, the tail of resulting in-degree
-    distribution of the directed case is given by
+    where :math:`k` is the (in-)degree of the vertex (or simply the degree in
+    the undirected case).
+
+    Note that for directed graphs we must have :math:`c \ge 0`, and for
+    undirected graphs, :math:`c > -\min(k_{\text{min}}, m)^{\gamma}`, where
+    :math:`k_{\text{min}}` is the smallest degree in the seed graph.
+
+    If :math:`\gamma=1`, the tail of resulting in-degree distribution of the
+    directed case is given by
 
     .. math::
 
@@ -1786,7 +1792,7 @@ def price_network(N, m=1, c=None, gamma=1, directed=True, seed_graph=None):
     scale-free (see [dorogovtsev-evolution]_ for details).
 
     Note that if `seed_graph` is not given, the algorithm will *always* start
-    with one node if :math:`c > 0`, or with two nodes with a link between them
+    with one node if :math:`c > 0`, or with two nodes with an edge between them
     otherwise. If :math:`m > 1`, the degree of the newly added vertices will be
     vary dynamically as :math:`m'(t) = \min(m, V(t))`, where :math:`V(t)` is the
     number of vertices added so far. If this behaviour is undesired, a proper
@@ -1849,6 +1855,7 @@ def price_network(N, m=1, c=None, gamma=1, directed=True, seed_graph=None):
     .. [dorogovtsev-evolution] S. N. Dorogovtsev and J. F. F. Mendes, "Evolution
        of networks", Advances in Physics, 2002, Vol. 51, No. 4, 1079-1187,
        :doi:`10.1080/00018730110112519`
+
     """
 
     if c is None:
@@ -1864,7 +1871,13 @@ def price_network(N, m=1, c=None, gamma=1, directed=True, seed_graph=None):
         N -= g.num_vertices()
     else:
         g = seed_graph
+
+    if ((directed and c < 0) or
+        (not directed and c <= -min(g.degree_property_map("out").fa.min(), m) ** gamma)):
+        raise ValueError("Parameter 'c' is too small, and yields negative probabilities")
+
     libgraph_tool_generation.price(g._Graph__graph, N, gamma, c, m, _get_rng())
+
     return g
 
 def condensation_graph(g, prop, vweight=None, eweight=None, avprops=None,
@@ -1877,16 +1890,16 @@ def condensation_graph(g, prop, vweight=None, eweight=None, avprops=None,
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be modelled.
-    prop : :class:`~graph_tool.PropertyMap`
+    prop : :class:`~graph_tool.VertexPropertyMap`
         Vertex property map with the community partition.
-    vweight : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    vweight : :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
         Vertex property map with the optional vertex weights.
-    eweight : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    eweight : :class:`~graph_tool.EdgePropertyMap` (optional, default: None)
         Edge property map with the optional edge weights.
-    avprops : list of :class:`~graph_tool.PropertyMap` (optional, default: None)
+    avprops : list of :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
         If provided, the sum of each property map in this list for
         each vertex in the condensed graph will be computed and returned.
-    aeprops : list of :class:`~graph_tool.PropertyMap` (optional, default: None)
+    aeprops : list of :class:`~graph_tool.EdgePropertyMap` (optional, default: None)
         If provided, the sum of each property map in this list for
         each edge in the condensed graph will be computed and returned.
     self_loops : ``bool`` (optional, default: ``False``)
@@ -1901,16 +1914,16 @@ def condensation_graph(g, prop, vweight=None, eweight=None, avprops=None,
     -------
     condensation_graph : :class:`~graph_tool.Graph`
         The community network
-    prop : :class:`~graph_tool.PropertyMap`
+    prop : :class:`~graph_tool.VertexPropertyMap`
         The community values.
-    vcount : :class:`~graph_tool.PropertyMap`
+    vcount : :class:`~graph_tool.VertexPropertyMap`
         A vertex property map with the vertex count for each community.
-    ecount : :class:`~graph_tool.PropertyMap`
+    ecount : :class:`~graph_tool.EdgePropertyMap`
         An edge property map with the inter-community edge count for each edge.
-    va : list of :class:`~graph_tool.PropertyMap`
+    va : list of :class:`~graph_tool.VertexPropertyMap`
         A list of vertex property maps with summed values of the properties
         passed via the ``avprops`` parameter.
-    ea : list of :class:`~graph_tool.PropertyMap`
+    ea : list of :class:`~graph_tool.EdgePropertyMap`
         A list of edge property maps with summed values of the properties
         passed via the ``avprops`` parameter.
 
