@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -103,6 +103,13 @@ State classes
    ~graph_tool.inference.uncertain_blockmodel.MixedMeasuredBlockState
    ~graph_tool.inference.uncertain_blockmodel.UncertainBlockState
    ~graph_tool.inference.uncertain_blockmodel.UncertainBaseState
+   ~graph_tool.inference.uncertain_blockmodel.DynamicsBlockStateBase
+   ~graph_tool.inference.uncertain_blockmodel.EpidemicsBlockState
+   ~graph_tool.inference.uncertain_blockmodel.IsingBaseBlockState
+   ~graph_tool.inference.uncertain_blockmodel.IsingGlauberBlockState
+   ~graph_tool.inference.uncertain_blockmodel.CIsingGlauberBlockState
+   ~graph_tool.inference.uncertain_blockmodel.PseudoIsingBlockState
+   ~graph_tool.inference.uncertain_blockmodel.PseudoCIsingBlockState
 
 Semiparametric stochastic block model inference
 +++++++++++++++++++++++++++++++++++++++++++++++
@@ -151,6 +158,11 @@ __all__ = ["minimize_blockmodel_dl",
            "MeasuredBlockState",
            "UncertainBaseState",
            "MixedMeasuredBlockState",
+           "EpidemicsBlockState",
+           "IsingGlauberBlockState",
+           "PseudoIsingBlockState",
+           "CIsingGlauberBlockState",
+           "PseudoCIsingBlockState",
            "mcmc_equilibrate",
            "mcmc_anneal",
            "mcmc_multilevel",
@@ -170,7 +182,8 @@ __all__ = ["minimize_blockmodel_dl",
            "half_edge_graph",
            "get_block_edge_gradient",
            "get_hierarchy_tree",
-           "modularity"]
+           "modularity",
+           "latent_multigraph"]
 
 from . blockmodel import *
 from . overlap_blockmodel import *
@@ -183,3 +196,4 @@ from . minimize import *
 from . blockmodel_em import *
 from . util import *
 from . modularity import *
+from . latent_multigraph import *
