@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ Summary
    incidence
    transition
    modularity_matrix
+   hashimoto
 
 Contents
 ++++++++
@@ -40,7 +41,8 @@ Contents
 
 from __future__ import division, absolute_import, print_function
 
-from .. import _degree, _prop, Graph, GraphView, _limit_args
+from .. import _degree, _prop, Graph, GraphView, _limit_args, Vector_int64_t, \
+    Vector_double
 from .. stats import label_self_loops
 import numpy
 import scipy.sparse
@@ -49,7 +51,8 @@ import scipy.sparse.linalg
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_spectral")
 
-__all__ = ["adjacency", "laplacian", "incidence", "transition", "modularity_matrix"]
+__all__ = ["adjacency", "laplacian", "incidence", "transition",
+           "modularity_matrix", "hashimoto"]
 
 
 def adjacency(g, weight=None, index=None):
@@ -59,24 +62,24 @@ def adjacency(g, weight=None, index=None):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    weight : :class:`~graph_tool.PropertyMap` (optional, default: True)
+    weight : :class:`~graph_tool.EdgePropertyMap` (optional, default: True)
         Edge property map with the edge weights.
-    index : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    index : :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
         Vertex property map specifying the row/column indexes. If not provided, the
         internal vertex index is used.
 
     Returns
     -------
-    a : :class:`~scipy.sparse.csr_matrix`
+    A : :class:`~scipy.sparse.csr_matrix`
         The (sparse) adjacency matrix.
 
     Notes
     -----
-    The adjacency matrix is defined as
+    For undirected graphs, the adjacency matrix is defined as
 
     .. math::
 
-        a_{i,j} =
+        A_{ij} =
         \begin{cases}
             1 & \text{if } (j, i) \in E, \\
             2 & \text{if } i = j \text{ and } (i, i) \in E, \\
@@ -85,16 +88,27 @@ def adjacency(g, weight=None, index=None):
 
     where :math:`E` is the edge set.
 
+    For directed graphs, we have instead simply
+
+    .. math::
+
+        A_{ij} =
+        \begin{cases}
+            1 & \text{if } (j, i) \in E, \\
+            0 & \text{otherwise}.
+        \end{cases}
+
     In the case of weighted edges, the entry values are multiplied by the weight
     of the respective edge.
 
     In the case of networks with parallel edges, the entries in the matrix
-    become simply the edge multiplicities (or twice them for the diagonal).
+    become simply the edge multiplicities (or twice them for the diagonal, for
+    undirected graphs).
 
     .. note::
 
         For directed graphs the definition above means that the entry
-        :math:`a_{i,j}` corresponds to the directed edge :math:`j\to
+        :math:`A_{ij}` corresponds to the directed edge :math:`j\to
         i`. Although this is a typical definition in network and graph theory
         literature, many also use the transpose of this matrix.
 
@@ -123,7 +137,7 @@ def adjacency(g, weight=None, index=None):
     .. testcode::
        :hide:
 
-       savefig("adjacency-spectrum.png")
+       savefig("adjacency-spectrum.svg")
 
     .. figure:: adjacency-spectrum.*
         :align: center
@@ -133,6 +147,7 @@ def adjacency(g, weight=None, index=None):
     References
     ----------
     .. [wikipedia-adjacency] http://en.wikipedia.org/wiki/Adjacency_matrix
+
     """
 
     if index is None:
@@ -173,9 +188,9 @@ def laplacian(g, deg="total", normalized=False, weight=None, index=None):
         Degree to be used, in case of a directed graph.
     normalized : bool (optional, default: False)
         Whether to compute the normalized Laplacian.
-    weight : :class:`~graph_tool.PropertyMap` (optional, default: True)
+    weight : :class:`~graph_tool.EdgePropertyMap` (optional, default: True)
         Edge property map with the edge weights.
-    index : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    index : :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
         Vertex property map specifying the row/column indexes. If not provided, the
         internal vertex index is used.
 
@@ -248,7 +263,7 @@ def laplacian(g, deg="total", normalized=False, weight=None, index=None):
     .. testcode::
        :hide:
 
-       savefig("laplacian-spectrum.png")
+       savefig("laplacian-spectrum.svg")
 
     .. figure:: laplacian-spectrum.*
         :align: center
@@ -272,7 +287,7 @@ def laplacian(g, deg="total", normalized=False, weight=None, index=None):
     .. testcode::
        :hide:
 
-       savefig("norm-laplacian-spectrum.png")
+       savefig("norm-laplacian-spectrum.svg")
 
     .. figure:: norm-laplacian-spectrum.*
         :align: center
@@ -325,10 +340,10 @@ def incidence(g, vindex=None, eindex=None):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    vindex : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    vindex : :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
         Vertex property map specifying the row indexes. If not provided, the
         internal vertex index is used.
-    eindex : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    eindex : :class:`~graph_tool.EdgePropertyMap` (optional, default: None)
         Edge property map specifying the column indexes. If not provided, the
         internal edge index is used.
 
@@ -371,7 +386,7 @@ def incidence(g, vindex=None, eindex=None):
     >>> print(m.todense())
     [[-1. -1.  0. ...  0.  0.  0.]
      [ 0.  0.  0. ...  0.  0.  0.]
-     [ 0.  0.  0. ...  0.  0.  0.]
+     [ 1.  0.  0. ...  0.  0.  0.]
      ...
      [ 0.  0. -1. ...  0.  0.  0.]
      [ 0.  0.  0. ...  0.  0.  0.]
@@ -418,9 +433,9 @@ def transition(g, weight=None, index=None):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    weight : :class:`~graph_tool.PropertyMap` (optional, default: True)
+    weight : :class:`~graph_tool.EdgePropertyMap` (optional, default: True)
         Edge property map with the edge weights.
-    index : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    index : :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
         Vertex property map specifying the row/column indexes. If not provided, the
         internal vertex index is used.
 
@@ -476,7 +491,7 @@ def transition(g, weight=None, index=None):
     .. testcode::
        :hide:
 
-       savefig("transition-spectrum.png")
+       savefig("transition-spectrum.svg")
 
     .. figure:: transition-spectrum.*
         :align: center
@@ -520,9 +535,9 @@ def modularity_matrix(g, weight=None, index=None):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    weight : :class:`~graph_tool.PropertyMap` (optional, default: True)
+    weight : :class:`~graph_tool.EdgePropertyMap` (optional, default: True)
         Edge property map with the edge weights.
-    index : :class:`~graph_tool.PropertyMap` (optional, default: None)
+    index : :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
         Vertex property map specifying the row/column indexes. If not provided, the
         internal vertex index is used.
 
@@ -573,7 +588,7 @@ def modularity_matrix(g, weight=None, index=None):
     .. testcode::
        :hide:
 
-       savefig("modularity-spectrum.png")
+       savefig("modularity-spectrum.svg")
 
     .. figure:: modularity-spectrum.*
         :align: center
@@ -616,3 +631,130 @@ def modularity_matrix(g, weight=None, index=None):
                                            dtype="float")
 
     return B
+
+def hashimoto(g, index=None, compact=False):
+    r"""Return the Hashimoto (or non-backtracking) matrix of a graph.
+
+    Parameters
+    ----------
+    g : :class:`~graph_tool.Graph`
+        Graph to be used.
+    index : :class:`~graph_tool.VertexPropertyMap` (optional, default: None)
+        Edge property map specifying the row/column indexes. If not provided, the
+        internal edge index is used.
+    compact : ``boolean`` (optional, default: ``False``)
+        If ``True``, a compact :math:`2|V|\times 2|V|` version of the matrix is
+        returned.
+
+    Returns
+    -------
+    H : :class:`~scipy.sparse.csr_matrix`
+        The (sparse) Hashimoto matrix.
+
+    Notes
+    -----
+    The Hashimoto (a.k.a. non-backtracking) matrix is defined as
+
+    .. math::
+
+        h_{k\to l,i\to j} =
+        \begin{cases}
+            1 & \text{if } (k,l) \in E, (i,j) \in E, l=i, k\ne j,\\
+            0 & \text{otherwise},
+        \end{cases}
+
+    where :math:`E` is the edge set. It is therefore a :math:`2|E|\times 2|E|`
+    asymmetric square matrix (or :math:`|E|\times |E|` for directed graphs),
+    indexed over edge directions.
+
+    If the option ``compact=True`` is passed, the matrix returned has shape
+    :math:`2|V|\times 2|V|`, where :math:`|V|` is the number of vertices, and is
+    given by
+
+    .. math::
+
+        \boldsymbol h =
+        \left(\begin{array}{c|c}
+            \boldsymbol A & -\boldsymbol 1 \\ \hline
+            \boldsymbol D-\boldsymbol 1 & \boldsymbol 0
+        \end{array}\right)
+
+    where :math:`\boldsymbol A` is the adjacency matrix, and :math:`\boldsymbol
+    D` is the diagonal matrix with the node degrees.
+
+    Examples
+    --------
+    .. testsetup::
+
+       import scipy.linalg
+       from pylab import *
+
+    >>> g = gt.collection.data["football"]
+    >>> H = gt.hashimoto(g)
+    >>> ew, ev = scipy.linalg.eig(H.todense())
+    >>> figure(figsize=(8, 4))
+    <...>
+    >>> scatter(real(ew), imag(ew), c=sqrt(abs(ew)), linewidths=0, alpha=0.6)
+    <...>
+    >>> xlabel(r"$\operatorname{Re}(\lambda)$")
+    Text(...)
+    >>> ylabel(r"$\operatorname{Im}(\lambda)$")
+    Text(...)
+    >>> tight_layout()
+    >>> savefig("hashimoto-spectrum.pdf")
+
+    .. testcode::
+       :hide:
+
+       savefig("hashimoto-spectrum.svg")
+
+    .. figure:: hashimoto-spectrum.*
+        :align: center
+
+        Hashimoto matrix spectrum for the network of American football teams.
+
+    References
+    ----------
+    .. [hashimoto] Hashimoto, Ki-ichiro. "Zeta functions of finite graphs and
+       representations of p-adic groups." Automorphic forms and geometry of
+       arithmetic varieties. 1989. 211-280. :DOI:`10.1016/B978-0-12-330580-0.50015-X`
+    .. [krzakala_spectral] Florent Krzakala, Cristopher Moore, Elchanan Mossel,
+       Joe Neeman, Allan Sly, Lenka Zdeborová, and Pan Zhang, "Spectral redemption
+       in clustering sparse networks", PNAS 110 (52) 20935-20940, 2013.
+       :doi:`10.1073/pnas.1312486110`, :arxiv:`1306.5550`
+
+    """
+
+    if compact:
+        i = Vector_int64_t()
+        j = Vector_int64_t()
+        x = Vector_double()
+
+        libgraph_tool_spectral.compact_nonbacktracking(g._Graph__graph,
+                                                       i, j, x)
+
+        N = g.num_vertices(ignore_filter=True)
+        m = scipy.sparse.coo_matrix((x, (i.a,j.a)), shape=(2 * N, 2 * N))
+    else:
+        if index is None:
+            if g.get_edge_filter()[0] is not None:
+                index = g.new_edge_property("int64_t")
+                index.fa = numpy.arange(g.num_edges())
+                E = index.fa.max() + 1
+            else:
+                index = g.edge_index
+                E = g.edge_index_range
+
+        if not g.is_directed():
+            E *= 2
+
+        i = Vector_int64_t()
+        j = Vector_int64_t()
+
+        libgraph_tool_spectral.nonbacktracking(g._Graph__graph, _prop("e", g, index),
+                                               i, j)
+
+        data = numpy.ones(i.a.shape)
+        m = scipy.sparse.coo_matrix((data, (i.a,j.a)), shape=(E, E))
+    m = m.tocsr()
+    return m
